@@ -212,7 +212,7 @@ void Adapter_impl::suspend(long streamID)
 bool Adapter_impl::active(long streamID)
 {
 	Stream stream = findStream(streamID);
-	arts_return_val_if_fail(!stream.isNull(), false)
+	arts_return_val_if_fail(!stream.isNull(), false);
 
 	return stream.active();
 }
@@ -241,7 +241,7 @@ StreamStatus Adapter_impl::status(long streamID)
 void Adapter_impl::clearBuffer(long streamID)
 {
 	Stream stream = findStream(streamID);
-	arts_return_if_fail(!stream.isNull())
+	arts_return_if_fail(!stream.isNull());
 
 	stream.clearBuffer();
 }
