@@ -70,7 +70,6 @@ static CslErrorType  arts_pcm_stream_init		(CslDriver       *driver,
 							 unsigned int     n_channels,
 							 CslPcmFormatType format,
 							 CslBool	  readable,
-							 CslBool	  writable,
 							 CslPcmStream	**stream_p);
 static void	     arts_pcm_stream_destroy            (CslPcmStream    *stream);
 static int	     arts_pcm_read               	(CslPcmStream    *stream,
@@ -82,19 +81,15 @@ static int	     arts_pcm_write              	(CslPcmStream    *stream,
 static CslErrorType  arts_pcm_update_status         	(CslPcmStream    *stream);
 static CslErrorType  arts_pcm_sync               	(CslPcmStream    *stream);
 static CslErrorType  arts_pcm_flush              	(CslPcmStream    *stream);
-static CslErrorType  arts_pcm_activate           	(CslPcmStream    *stream);
-static CslErrorType  arts_pcm_suspend            	(CslPcmStream    *stream);
 static CslErrorType  arts_pcm_set_title          	(CslPcmStream   *stream,
 							 const char     *title);
 static CslErrorType  arts_pcm_set_stream_mode    	(CslPcmStream   *stream,
-							 unsigned int    buffer_size);
-static CslErrorType  arts_pcm_set_stream_watermark	(CslPcmStream   *stream,
-							 unsigned int    n_bytes);
+							 unsigned int    buffer_size,
+							 unsigned int    byte_watermark);
 static CslErrorType  arts_pcm_set_packet_mode		(CslPcmStream   *stream,
-							 unsigned int    n_packets,
-							 unsigned int    packet_size);
-static CslErrorType  arts_pcm_set_packet_watermark	(CslPcmStream   *stream,
-							 unsigned int    n_packets);
+							 unsigned int	 n_packets,
+							 unsigned int	 packet_size,
+							 unsigned int	 packet_watermark);
 static CslErrorType  arts_pcm_set_channel_mapping       (CslPcmStream   *stream,
 							 unsigned int    channel,
 							 const char     *mapping);
@@ -140,13 +135,9 @@ CslPcmDriverVTable _csl_arts_pcm_vtable = {
   arts_pcm_update_status,
   arts_pcm_sync,
   arts_pcm_flush,
-  arts_pcm_activate,
-  arts_pcm_suspend,
   arts_pcm_set_title,
   arts_pcm_set_stream_mode,
-  arts_pcm_set_stream_watermark,
   arts_pcm_set_packet_mode,
-  arts_pcm_set_packet_watermark,
   arts_pcm_set_channel_mapping,
 };
 
@@ -301,7 +292,6 @@ arts_pcm_stream_init (CslDriver       *driver,
 		      unsigned int     n_channels,
 		      CslPcmFormatType format,
 		      CslBool	      readable,
-		      CslBool	      writable,
 		      CslPcmStream   **stream_p)
 {
   CslPcmDriver *pcm_driver = driver->pcm_data;
@@ -310,11 +300,10 @@ arts_pcm_stream_init (CslDriver       *driver,
   int stream_id;
   int direction = readable ? ARTS_CSL_DIR_INPUT : ARTS_CSL_DIR_OUTPUT;
   
-  csl_return_val_if_fail ((writable && !readable) || (readable && !writable), CSL_EINTERN);
-  
   stream_id = _arts_csl_adapter_open (pcm_driver->adapter, role, direction);
   if (!stream_id)
     return CSL_EIO;	/* this only happens if the server failed badly somehow (i.e. crash) */
+  _arts_csl_adapter_activate (pcm_driver->adapter, stream_id);
   
   stream = csl_new0 (ArtsPcmStream, 1);
   stream->stream.driver = driver;
@@ -322,14 +311,14 @@ arts_pcm_stream_init (CslDriver       *driver,
   stream->stream.title = NULL;
   stream->stream.blocking = TRUE;
   stream->stream.readable = readable;
-  stream->stream.writable = writable;
   stream->stream.packet_mode = FALSE;
   stream->stream.stream_mode = !stream->stream.packet_mode;
-  stream->stream.active = FALSE;
   stream->stream.n_channels = n_channels;
   stream->stream.channel_mappings = NULL;
   stream->stream.format = format;
   stream->stream.rate = rate;
+  stream->stream.writable = !readable;
+  stream->stream.readable = readable;
   
   /* pick buffering defaults for Arts fragments (packet_mode = TRUE)
      stream->stream.packet.n_total_packets = 128;
@@ -517,33 +506,6 @@ arts_pcm_sync (CslPcmStream *_stream)
   return CSL_ENONE;
 }
 
-static CslErrorType
-arts_pcm_activate (CslPcmStream *_stream)
-{
-  CslPcmDriver *pcm_driver = _stream->driver->pcm_data;
-  ArtsPcmStream *stream = ARTS_PCM_STREAM (_stream);
-  
-  stream->stream.active = TRUE;
-  _arts_csl_adapter_activate (pcm_driver->adapter, stream->id);
-  
-  return CSL_ENONE;
-}
-
-static CslErrorType
-arts_pcm_suspend (CslPcmStream *_stream)
-{
-  ArtsPcmStream *stream = ARTS_PCM_STREAM (_stream);
-  
-  arts_pcm_sync (_stream);
-  
-  stream->stream.active = FALSE;
-  
-  /* FIXME */
-  /* read up in arts_pcm_activate() to learn about an imperfect world */
-  
-  return CSL_ENONE;
-}
-
 static CslErrorType
 arts_pcm_set_title (CslPcmStream *_stream,
 		    const char   *title)
@@ -560,72 +522,22 @@ arts_pcm_set_title (CslPcmStream *_stream,
 
 static CslErrorType
 arts_pcm_set_stream_mode (CslPcmStream   *stream,
-			  unsigned int    buffer_size)
+			  unsigned int    buffer_size,
+			  unsigned int    byte_watermark)
 {
-  /* FIXME: someone implement streaming->fragment aproximation for Arts */
-  return CSL_ECAPSUPPORT;
-}
-
-static CslErrorType
-arts_pcm_set_stream_watermark (CslPcmStream   *stream,
-			       unsigned int    n_bytes)
-{
-  /* FIXME: someone implement streaming->fragment aproximation for Arts */
+  /* FIXME: implement watermark */
+  csl_warning ("FIXME: watermark not implemented for aRts driver");
   return CSL_ECAPSUPPORT;
 }
 
 static CslErrorType
 arts_pcm_set_packet_mode	(CslPcmStream   *_stream,
-				 unsigned int    n_packets,
-				 unsigned int    packet_size)
+				 unsigned int	 n_packets,
+				 unsigned int	 packet_size,
+				 unsigned int	 packet_watermark)
 {
   csl_warning ("FIXME: packet mode not implemented for aRts driver");
   return CSL_ENONE;
-#if 0
-  ArtsPcmStream *stream = ARTS_PCM_STREAM (_stream);
-  CslErrorType error;
-  
-  stream->stream.packet_mode = TRUE;
-  stream->stream.stream_mode = FALSE;
-  
-  (void) ioctl (stream->fd, SNDCTL_DSP_RESET);
-  
-  /* setup Arts fragments */
-  stream->stream.packet.n_total_packets = n_packets;
-  stream->stream.packet.packet_size = packet_size;
-  stream->stream.packet.n_packets_available = 0; /* unused in _setup() */
-  stream->stream.packet.packet_watermark = 1; /* Arts supports just one packet */
-  
-  /* setup buffering values based on default packet setup */
-  stream->stream.buffer_size = (stream->stream.packet.n_total_packets *
-				stream->stream.packet.packet_size);
-  stream->stream.n_bytes_available = 0; /* unused in _setup() */
-  stream->stream.buffer_watermark = (stream->stream.packet.packet_size *
-				     stream->stream.packet.packet_watermark);
-  
-  /* close eyes, crarts fingers */
-  csl_free (stream->stream.channel_mappings);
-  stream->stream.channel_mappings = NULL;
-  error = pcm_device_arts_setup (stream);
-  
-  /* _setup() didn't fill in buffer settings */
-  arts_pcm_update_status (&stream->stream);
-  
-  return error;
-#endif
-  /* FIXME */
-  return CSL_ENODRIVER;
-}
-
-static CslErrorType
-arts_pcm_set_packet_watermark (CslPcmStream   *stream,
-			       unsigned int    n_packets)
-{
-  /* user is supposed to read-out real watermark after invoking this
-   * function, for Arts it's constant 1, yes, suckage
-   */
-  /* FIXME */
-  return CSL_ENONE;
 }
 
 static CslErrorType
@@ -942,5 +854,4 @@ arts_sample_cache_remove (CslSample *_sample)
   _arts_csl_adapter_sample_cache_remove (pcm_driver->adapter, sample->id);
 }
 
-/* vim:ts=8:sw=2:sts=2
- */
+/* vim:set ts=8 sw=2 sts=2: */
