@@ -80,7 +80,10 @@ _arts_mcop_dispatcher_new (const char *server_spec,
   char *tmp, *string, *dom;
   int i;
   
-  dispatcher->timeout = 1000;	/* milliseconds */
+  /* _arts_csl_adapter_sample_wait_done can take virtually forever, so no
+   * 1000ms timeout here:
+   * dispatcher->timeout = 1000; */
+  dispatcher->timeout = -1;
   
   /* find a socket to connect to server */
   if (!dispatcher->csock && server_spec)
@@ -271,7 +274,11 @@ _arts_mcop_dispatcher_free_request (ArtsMcopDispatcher *dispatcher,
       if (request->result.v_object)
 	_arts_mcop_object_reference_free (request->result.v_object);
       break;
-    default:
+    case ARTS_MCOP_RESULT_CUSTOM:
+      if (request->result.v_custom.free != NULL && request->result.v_custom.data != NULL)
+	request->result.v_custom.free (request->result.v_custom.data);
+      break;
+     default:
       break;
     }
   request->result_type = ARTS_MCOP_RESULT_VOID;
@@ -342,6 +349,10 @@ _arts_mcop_dispatcher_process_message (ArtsMcopDispatcher *dispatcher)
 		    case ARTS_MCOP_RESULT_OBJECT:
 		      dispatcher->requests[request_id].result.v_object = _arts_mcop_object_reference_demarshal (&msg_buffer);
 		      break;
+		    case ARTS_MCOP_RESULT_CUSTOM:
+		      dispatcher->requests[request_id].result.v_custom.data =
+			dispatcher->requests[request_id].result.v_custom.demarshal (&msg_buffer);
+		      break;
 		    }
 		  dispatcher->requests[request_id].completed = TRUE;
 		  dispatcher->requests[request_id].result_broken = msg_buffer.error;
