@@ -163,8 +163,8 @@ typedef struct _CslOptions CslOptions;
  */
 struct _CslOptions
 {
-   /** 1 if samples are of type float (-F option) */
-  unsigned int  float_samples : 1;    
+  /** 1 if samples are of type float (-F option) */
+  unsigned int  float_samples : 1;	/* whether samples are of type float (-F option) */
   /** 1 if samples are signed values (-s option) */
   unsigned int  signed_samples : 1;
   /** 1 if samples are unsigned values (-u option) */
@@ -197,6 +197,21 @@ char*	csl_options_describe	(unsigned int	  indent);
 
 char*	csl_describe_pcm_format	(unsigned int     pcm_format);
 
+
+#if 0	/* Proposed */
+typedef struct _CslPollFD {
+  int fd;           /* file descriptor */
+  unsigned short events;     /* requested events */
+  unsigned short revents;    /* returned events */
+} CslPollFD;
+
+unsigned int csl_poll_count_fds (void);
+unsigned int csl_poll_get_fds (unsigned int n_fds, CslPollFD *fds);
+void csl_poll_handle_fds (unsigned int n_fds, CslPollFD *fds);
+void csl_poll_wait (unsigned int time_in_ms);
+#endif
+
+
 #ifdef __cplusplus
 }
 #endif /* __cplusplus */
