@@ -31,11 +31,10 @@ pcm_open_internal (CslDriver       *driver,
 		   unsigned int     n_channels,
 		   CslPcmFormatType format,
 		   CslBool          readable,
-		   CslBool          writable,
 		   CslPcmStream   **stream_p)
 {
   CslErrorType error;
-  CslPcmStream *stream;
+  CslPcmStream *stream = NULL;
 
   csl_return_val_if_fail (driver != NULL, CSL_EINTERN);
   csl_return_val_if_fail (driver->pcm_vtable != NULL, CSL_EINTERN);
@@ -49,16 +48,14 @@ pcm_open_internal (CslDriver       *driver,
 					   rate,
 					   n_channels,
 					   format,
-					   readable, writable,
+					   readable,
 					   &stream);
-  if (!error && !stream->active)
-    {
-      error = driver->pcm_vtable->activate (stream);
-      if (error)
-	driver->pcm_vtable->stream_destroy (stream);
-    }
   if (error)
-    *stream_p = NULL;
+    {
+      if (stream)
+	driver->pcm_vtable->stream_destroy (stream);
+      *stream_p = NULL;
+    }
   else
     *stream_p = stream;
 
@@ -99,7 +96,7 @@ csl_pcm_open_output (CslDriver       *driver,
 			    rate,
 			    n_channels,
 			    format,
-			    FALSE, TRUE,
+			    FALSE,
 			    stream_p);
 }
 
@@ -131,7 +128,7 @@ csl_pcm_open_input (CslDriver       *driver,
 			    rate,
 			    n_channels,
 			    format,
-			    TRUE, FALSE,
+			    TRUE,
 			    stream_p);
 }
 
@@ -194,8 +191,8 @@ csl_pcm_read (CslPcmStream    *stream,
   csl_return_val_if_fail (stream != NULL, CSL_EINTERN);
   csl_return_val_if_fail (stream->driver != NULL, CSL_EINTERN);
   csl_return_val_if_fail (stream->readable == TRUE, CSL_EINTERN);
-  csl_return_val_if_fail (stream->active == TRUE, CSL_EINTERN);
 
+  stream->accessed = TRUE;
   if (n_bytes)
     {
       csl_return_val_if_fail (bytes != NULL, CSL_EINTERN);
@@ -232,8 +229,8 @@ csl_pcm_write (CslPcmStream    *stream,
   csl_return_val_if_fail (stream != NULL, CSL_EINTERN);
   csl_return_val_if_fail (stream->driver != NULL, CSL_EINTERN);
   csl_return_val_if_fail (stream->writable == TRUE, CSL_EINTERN);
-  csl_return_val_if_fail (stream->active == TRUE, CSL_EINTERN);
 
+  stream->accessed = TRUE;
   if (n_bytes)
     {
       driver = stream->driver;
@@ -265,7 +262,6 @@ csl_pcm_get_status (CslPcmStream *stream,
   csl_return_val_if_fail (stream != NULL, CSL_EINTERN);
   csl_return_val_if_fail (stream->driver != NULL, CSL_EINTERN);
   csl_return_val_if_fail (status != NULL, CSL_EINTERN);
-  csl_return_val_if_fail (stream->active == TRUE, CSL_EINTERN);
 
   driver = stream->driver;
   DRIVER_LOCK (driver);
@@ -330,7 +326,6 @@ csl_pcm_flush (CslPcmStream *stream)
 
   csl_return_val_if_fail (stream != NULL, CSL_EINTERN);
   csl_return_val_if_fail (stream->driver != NULL, CSL_EINTERN);
-  csl_return_val_if_fail (stream->active == TRUE, CSL_EINTERN);
 
   driver = stream->driver;
   DRIVER_LOCK (driver);
@@ -359,7 +354,6 @@ csl_pcm_sync (CslPcmStream *stream)
 
   csl_return_val_if_fail (stream != NULL, CSL_EINTERN);
   csl_return_val_if_fail (stream->driver != NULL, CSL_EINTERN);
-  csl_return_val_if_fail (stream->active == TRUE, CSL_EINTERN);
 
   driver = stream->driver;
   DRIVER_LOCK (driver);
@@ -369,57 +363,6 @@ csl_pcm_sync (CslPcmStream *stream)
   return error;
 }
 
-/**
- * Activate a previously suspended PCM stream, allowing it to transfer data again.
- * 
- * @param stream The PCM stream to activate.
- * @see csl_pcm_suspend
- * @short Activate a PCM stream.
- */
-CslErrorType
-csl_pcm_activate (CslPcmStream *stream)
-{
-  CslDriver *driver;
-  CslErrorType error;
-
-  csl_return_val_if_fail (stream != NULL, CSL_EINTERN);
-  csl_return_val_if_fail (stream->driver != NULL, CSL_EINTERN);
-  csl_return_val_if_fail (stream->active == FALSE, CSL_EINTERN);
-
-  driver = stream->driver;
-  DRIVER_LOCK (driver);
-  error = driver->pcm_vtable->activate (stream);
-  DRIVER_UNLOCK (driver);
-
-  return error;
-}
-
-/**
- * Suspend a PCM stream, preventing it from passing any further data
- * until activated.
- * 
- * @param stream The PCM stream to suspend.
- * @see csl_pcm_activate
- * @short Suspend a PCM stream.
- */
-CslErrorType
-csl_pcm_suspend (CslPcmStream *stream)
-{
-  CslDriver *driver;
-  CslErrorType error;
-
-  csl_return_val_if_fail (stream != NULL, CSL_EINTERN);
-  csl_return_val_if_fail (stream->driver != NULL, CSL_EINTERN);
-  csl_return_val_if_fail (stream->active == TRUE, CSL_EINTERN);
-
-  driver = stream->driver;
-  DRIVER_LOCK (driver);
-  error = driver->pcm_vtable->suspend (stream);
-  DRIVER_UNLOCK (driver);
-
-  return error;
-}
-
 /**
  * Associate a title string with the stream.  The title may be shown
  * to the end user to describe the stream. The title should be
@@ -482,125 +425,78 @@ csl_pcm_dup_title (CslPcmStream *stream)
 }
 
 /**
- * Set the buffer size for a stream to a new value.
- * (why is the name misleading?)
+ * Put the @ref CslPcmStream into streaming mode, or, if already in
+ * streaming mode, alter the buffer and watermark settings.
+ * For writable streams, the watermark indicates
+ * the amount of bytes that should be writable before csl_select()
+ * flags this stream as writable.
+ * For readable streams, this means the amount of bytes that should
+ * be readable before csl_select() flags this stream as readable.
+ * The resulting values strongly depend on the driver implementation
+ * and should be queried after invoking this function with
+ * csl_pcm_get_stream_settings().
  *
- * @param stream The PCM stream.
- * @param buffer_size The new buffer size, in bytes.
- * @return Error status code
- * @short Set stream buffer size.
- */
+ * @param stream          The PCM stream to change
+ * @param buffer_size     The buffer size in bytes for streaming mode
+ * @param byte_watermark  The fill state watermark into buffer 
+ * @return Whether setting stream parameters succeeded.
+ *
+ * @short Put PCM stream to streaming mode, set buffer settings.
+ **/
 CslErrorType
 csl_pcm_set_stream_mode (CslPcmStream *stream,
-			 unsigned int  buffer_size)
+			 unsigned int  buffer_size,
+			 unsigned int  byte_watermark)
 {
   CslDriver *driver;
   CslErrorType error;
 
   csl_return_val_if_fail (stream != NULL, CSL_EINTERN);
   csl_return_val_if_fail (stream->driver != NULL, CSL_EINTERN);
-  csl_return_val_if_fail (stream->active == FALSE, CSL_EINTERN);
 
   driver = stream->driver;
   DRIVER_LOCK (driver);
-  /* backend needs to make sure buffer_size is set correctly */
-  error = driver->pcm_vtable->set_stream_mode (stream, buffer_size);
+  error = driver->pcm_vtable->set_stream_mode (stream, buffer_size, byte_watermark);
   DRIVER_UNLOCK (driver);
 
   return error;
 }
 
 /**
- * Put stream in real-time packet mode, setting the number of packets
- * and packet size.
+ * Put the @ref CslPcmStream into packet mode, or, if already in
+ * packet mode, alter the buffer and watermark settings.
+ * For writable streams, the watermark indicates
+ * the amount of packets that should be writable before csl_select()
+ * flags this stream as writable.
+ * For readable streams, this means the amount of packets that should
+ * be readable before csl_select() flags this stream as readable.
+ * The resulting values strongly depend on the driver implementation
+ * and should be queried after invoking this function with
+ * csl_pcm_get_packet_settings().
  *
- * @param stream The PCM stream.
- * @param n_packets Number of packets.
- * @param packet_size Size of each packet, in bytes.
- * @return Error status code
+ * @param n_packets         Number of packets to be kept in buffer
+ * @param packet_size       Size of a packet in bytes
+ * @param packet_watermark  The fill state watermark in number of packets
+ * @returns Whether setting packet mode parameters succeeded.
  *
- * @short Put stream in packet mode.
- */
+ * @short Put PCM stream to packet mode, set buffer settings.
+ **/
 CslErrorType
 csl_pcm_set_packet_mode (CslPcmStream *stream,
 			 unsigned int  n_packets,
-			 unsigned int  packet_size)
+			 unsigned int  packet_size,
+			 unsigned int  packet_watermark)
 {
   CslDriver *driver;
   CslErrorType error;
 
   csl_return_val_if_fail (stream != NULL, CSL_EINTERN);
   csl_return_val_if_fail (stream->driver != NULL, CSL_EINTERN);
-  csl_return_val_if_fail (stream->active == FALSE, CSL_EINTERN);
 
   driver = stream->driver;
   DRIVER_LOCK (driver);
   /* backend needs to make sure n_packets && packet_size are set correctly */
-  error = driver->pcm_vtable->set_packet_mode (stream, n_packets, packet_size);
-  DRIVER_UNLOCK (driver);
-
-  return error;
-}
-
-/**
- * Set the watermark for a stream, i.e. the number of bytes that must
- * be pending in the buffer before the stream is written (is this
- * accurate?).
- *
- * @param stream The PCM stream.
- * @param n_bytes Number of bytes to set as watermark point.
- * @return Error status code
- * @see csl_pcm_set_packet_watermark
- * @short Set stream watermark.
- */
-CslErrorType
-csl_pcm_set_stream_watermark (CslPcmStream   *stream,
-			      unsigned int    n_bytes)
-{
-  CslDriver *driver;
-  CslErrorType error;
-
-  csl_return_val_if_fail (stream != NULL, CSL_EINTERN);
-  csl_return_val_if_fail (stream->driver != NULL, CSL_EINTERN);
-  csl_return_val_if_fail (stream->active == FALSE, CSL_EINTERN);
-  csl_return_val_if_fail (stream->stream_mode == TRUE, CSL_EINTERN);
-
-  driver = stream->driver;
-  DRIVER_LOCK (driver);
-  /* FIXME: should have buffer_size and watermark in stream struct, then assert them */
-  error = driver->pcm_vtable->set_stream_watermark (stream, n_bytes);
-  DRIVER_UNLOCK (driver);
-
-  return error;
-}
-
-/**
- * Set the watermark for a stream, i.e. the number of packets that must
- * be pending in the buffer before the stream is written (is this
- * accurate?).
- *
- * @param stream The PCM stream.
- * @param n_packets Number of packets to set as watermark point.
- * @return Error status code
- * @see csl_pcm_set_stream_watermark
- * @short Set stream watermark.
- */
-CslErrorType
-csl_pcm_set_packet_watermark (CslPcmStream   *stream,
-			      unsigned int    n_packets)
-{
-  CslDriver *driver;
-  CslErrorType error;
-
-  csl_return_val_if_fail (stream != NULL, CSL_EINTERN);
-  csl_return_val_if_fail (stream->driver != NULL, CSL_EINTERN);
-  csl_return_val_if_fail (stream->packet_mode == TRUE, CSL_EINTERN);
-  csl_return_val_if_fail (stream->active == FALSE, CSL_EINTERN);
-
-  driver = stream->driver;
-  DRIVER_LOCK (driver);
-  /* FIXME: should have n_packets, packet_size and watermark in stream struct, then assert them */
-  error = driver->pcm_vtable->set_packet_watermark (stream, n_packets);
+  error = driver->pcm_vtable->set_packet_mode (stream, n_packets, packet_size, packet_watermark);
   DRIVER_UNLOCK (driver);
 
   return error;
@@ -628,11 +524,10 @@ csl_pcm_get_stream_settings (CslPcmStream   *stream,
 
   driver = stream->driver;
   DRIVER_LOCK (driver);
-  /* FIXME: need buffer_size and watermark in stream struct */
   if (buffer_size_p)
-    *buffer_size_p = 0;
+    *buffer_size_p = stream->buffer_size;
   if (byte_watermark_p)
-    *byte_watermark_p = 0;
+    *byte_watermark_p = stream->buffer_watermark;
   DRIVER_UNLOCK (driver);
 }
 
@@ -660,7 +555,6 @@ csl_pcm_get_packet_settings (CslPcmStream   *stream,
 
   driver = stream->driver;
   DRIVER_LOCK (driver);
-  /* FIXME: need n_packets, packet_size and watermark in stream struct */
   if (n_packets_p)
     *n_packets_p = stream->packet.n_total_packets;
   if (packet_size_p)
@@ -670,6 +564,7 @@ csl_pcm_get_packet_settings (CslPcmStream   *stream,
   DRIVER_UNLOCK (driver);
 }
 
+#if 0		/* --- proposed --- */
 /**
  * List the mapping of channel names to channel numbers. These are the
  * global channel names supported by a driver, and are fixed. You can
@@ -743,3 +638,4 @@ csl_pcm_dup_channel_mapping (CslPcmStream *stream,
   /* FIXME */
   return NULL;
 }
+#endif	/* proposed channel mappings */
