@@ -83,6 +83,7 @@ typedef enum		/* keep in sync with cslarts.idl */
   CSL_PCM_FORMAT_FLOAT_BE                       = 0x3220,
 } CslPcmFormatType;
 
+/* defines for host endianess */
 #if CSL_BYTE_ORDER == CSL_LITTLE_ENDIAN
 #define CSL_PCM_FORMAT_S16_HE		CSL_PCM_FORMAT_S16_LE
 #define	CSL_PCM_FORMAT_FLOAT_HE		CSL_PCM_FORMAT_FLOAT_LE
@@ -103,11 +104,11 @@ struct _CslPcmStatus
   unsigned int	   rate;
   /** number of channels */
   unsigned int	   n_channels;
-  /** sample size in bits. (0==floats) n_bytes_per_value = (n_bits + 7) / 8 */
+  /** sample size in bits. (0==float32bit) n_bytes_per_value = (n_bits + 7) / 8 */
   unsigned int	   n_bits;
   CslPcmFormatType format;
   /** buffer_size = n_buffer_packets * packet_size * (n_bits + 7) / 8 */
-  unsigned int     buffer_size;
+  unsigned int     buffer_size; /* in bytes */
   /** # of bytes left to read or write */
   unsigned int	   n_bytes_available;
   unsigned int	   packet_size;
@@ -115,58 +116,77 @@ struct _CslPcmStatus
   /** # of empty packets left to read or write */
   unsigned int	   n_packets_available;
   unsigned int	   padding[128];
-  /*
-    CSL_PCM_PARAM_SERVER_LATENCY,
-    CSL_PCM_PARAM_TOTAL_LATENCY,
-    CSL_PCM_PARAM_BLOCKING,
-  */
+  /* server side latency in seconds
+   * (rate*server_latency==n_values_queued_on_server)
+   */
+  float		   server_latency;
 };
 
-CslErrorType csl_pcm_open_output		(CslDriver	*driver,
-						 const char     *role,
+CslErrorType csl_pcm_open_output		(CslDriver	 *driver,
+						 const char      *role,
 						 unsigned int	  rate,
 						 unsigned int	  n_channels,
 						 CslPcmFormatType format,
 						 CslPcmStream	**stream_p);
-
 CslErrorType csl_pcm_open_input			(CslDriver	 *driver,
 						 const char	 *role,
 						 unsigned int	  rate,
 						 unsigned int	  n_channels,
 						 CslPcmFormatType format,
 						 CslPcmStream   **stream_p);
-
+/* for coupled streams:
+ * flush affects all
+ * sync affects all
+ * behaviour for in-streams:
+ * flush: empty capture queue
+ * sync: NOP? (flush?)
+ */
 CslPcmFormatType csl_pcm_get_format		(CslPcmStream	 *stream);
-
 void		 csl_pcm_close			(CslPcmStream	 *stream);
 
 /* return n_bytes processed or -1==error (FIXME: need is_broken()) */
 int		 csl_pcm_read			(CslPcmStream    *stream,
 						 unsigned int     n_bytes,
 						 void            *bytes);
-
 int              csl_pcm_write                  (CslPcmStream    *stream,
 						 unsigned int     n_bytes,
 						 void            *bytes);
 
 CslErrorType	 csl_pcm_get_status		(CslPcmStream	 *stream,
 						 CslPcmStatus	 *status);
-
 CslErrorType	 csl_pcm_flush			(CslPcmStream	 *stream);
-
 CslErrorType	 csl_pcm_sync			(CslPcmStream	 *stream);
 
-CslErrorType	 csl_pcm_activate		(CslPcmStream	 *stream);
-
-CslErrorType	 csl_pcm_suspend		(CslPcmStream	 *stream);
 
 /* --- advanced API --- */
+/* buffer_size always in n_bytes */
+CslErrorType	csl_pcm_set_title		(CslPcmStream	*stream,
+						 const char	*title);
+char*		csl_pcm_dup_title		(CslPcmStream	*stream); /* needs csl_free() */
+CslErrorType	csl_pcm_set_stream_mode		(CslPcmStream	*stream,
+						 unsigned int	 buffer_size,
+						 unsigned int	 byte_watermark);
+void		csl_pcm_get_stream_settings	(CslPcmStream	*stream,
+						 unsigned int	*buffer_size_p,
+						 unsigned int	*byte_watermark_p);
+CslErrorType	csl_pcm_set_packet_mode		(CslPcmStream	*stream,
+						 unsigned int	 n_packets,
+						 unsigned int	 packet_size,
+						 unsigned int	 packet_watermark);
+void		csl_pcm_get_packet_settings	(CslPcmStream	*stream,
+						 unsigned int	*n_packets_p,
+						 unsigned int	*packet_size_p,
+						 unsigned int	*packet_watermark_p);
 
+
+/* --- proposed --- */
 #define CSL_PCM_CHANNEL_FRONT_LEFT	"<front-left>"
 #define CSL_PCM_CHANNEL_FRONT_RIGHT	"<front-right>"
 #define CSL_PCM_CHANNEL_CENTER		"<center>"
 #define CSL_PCM_CHANNEL_REAR_LEFT	"<rear-left>"
 #define CSL_PCM_CHANNEL_REAR_RIGHT	"<rear-right>"
+#define CSL_PCM_CHANNEL_SUB_WOOFER	"<sub-woofer>"
+#if 0
 /**
  * Channel names used for advanced API functions than manipulate
  * channel mappings.
@@ -176,51 +196,18 @@ CslErrorType	 csl_pcm_suspend		(CslPcmStream	 *stream);
  * @see csl_pcm_dup_channel_mapping
  * @short Channel names.
  */
-#define CSL_PCM_CHANNEL_SUB_WOOFER	"<sub-woofer>"
-
-/* buffer_size always in n_bytes */
-
-CslErrorType	csl_pcm_set_title		(CslPcmStream	*stream,
-						 const char	*title);
-
-char*		csl_pcm_dup_title		(CslPcmStream	*stream); /* needs free() */
-
-CslErrorType	csl_pcm_set_stream_mode		(CslPcmStream	*stream,
-						 unsigned int	 buffer_size);
-
-CslErrorType	csl_pcm_set_stream_watermark	(CslPcmStream	*stream,
-						 unsigned int	 n_bytes);
-
-void		csl_pcm_get_stream_settings	(CslPcmStream	*stream,
-						 unsigned int	*buffer_size_p,
-						 unsigned int	*byte_watermark_p);
-
-CslErrorType	csl_pcm_set_packet_mode		(CslPcmStream	*stream,
-						 unsigned int	 n_packets,
-						 unsigned int	 packet_size);
-
-CslErrorType	csl_pcm_set_packet_watermark	(CslPcmStream	*stream,
-						 unsigned int	 n_packets);
-
-void		csl_pcm_get_packet_settings	(CslPcmStream	*stream,
-						 unsigned int	*n_packets_p,
-						 unsigned int	*packet_size_p,
-						 unsigned int	*packet_watermark_p);
 
 CslErrorType	csl_pcm_set_channel_mapping	(CslPcmStream	*stream,
 						 unsigned int	 channel,
 						 const char	*mapping);
-
 char*		csl_pcm_dup_channel_mapping	(CslPcmStream	*stream,
 						 unsigned int	 channel);
-
 char**		csl_pcm_list_channel_mappings	(CslDriver	*driver,
 						 unsigned int	*n_maps_p);
+#endif
 
 #ifdef __cplusplus
 }
 #endif /* __cplusplus */
 
-#endif /* __CSL_PCM_H__ */
-/* vim:ts=8:sw=2:sts=2
- */
+#endif /* __CSL_PCM_H__ */ /* vim:set ts=8 sw=2 sts=2: */
