@@ -62,7 +62,7 @@ struct _CslPcmStream
   unsigned int writable : 1;
   unsigned int packet_mode : 1;
   unsigned int stream_mode : 1;
-  unsigned int active : 1;	/* !suspended */
+  unsigned int accessed : 1;	/* been written to or read from */
   unsigned int n_channels : 8;
   unsigned int format : 16;
   unsigned int rate;
@@ -83,18 +83,18 @@ struct _CslPcmStream
 };
 struct _CslPcmDriverVTable
 {
-  /* driver functions */
+  /* --- driver functions --- */
   CslErrorType	(*pcm_driver_init)	(CslDriver	*driver);
   void		(*pcm_driver_shutdown)	(CslDriver	*driver);
   
-  /* stream functions */
+
+  /* --- stream functions --- */
   CslErrorType	(*stream_init)		(CslDriver       *driver,
 					 const char	 *role,
 					 unsigned int	  rate,
 					 unsigned int	  n_channels,
 					 CslPcmFormatType format,
-					 CslBool          readable,
-					 CslBool          writable,
+					 CslBool          readable, /* FALSE==writable */
 					 CslPcmStream   **stream_p);
   void		(*stream_destroy)	(CslPcmStream	 *stream);
   int		(*read)			(CslPcmStream	 *stream,
@@ -106,19 +106,17 @@ struct _CslPcmDriverVTable
   CslErrorType	(*update_status)	(CslPcmStream	 *stream);
   CslErrorType	(*sync)			(CslPcmStream	 *stream);
   CslErrorType	(*flush)		(CslPcmStream	 *stream);
-  CslErrorType	(*activate)		(CslPcmStream	 *stream);
-  CslErrorType	(*suspend)		(CslPcmStream	 *stream);
   CslErrorType	(*set_title)		(CslPcmStream	*stream,
 					 const char	*title);
+  /* needs to reset packet mode */
   CslErrorType	(*set_stream_mode)	(CslPcmStream	*stream,
-					 unsigned int	 buffer_size);
-  CslErrorType	(*set_stream_watermark)	(CslPcmStream	*stream,
-					 unsigned int	 n_bytes);
+					 unsigned int	 buffer_size,
+					 unsigned int	 byte_watermark);
+  /* needs to reset stream mode */
   CslErrorType	(*set_packet_mode)	(CslPcmStream	*stream,
 					 unsigned int	 n_packets,
-					 unsigned int	 packet_size);
-  CslErrorType	(*set_packet_watermark)	(CslPcmStream	*stream,
-					 unsigned int	 n_packets);
+					 unsigned int	 packet_size,
+					 unsigned int	 packet_watermark);
   CslErrorType	(*set_channel_mapping)	(CslPcmStream	*stream,
 					 unsigned int	 channel,
 					 const char	*mapping);
