@@ -63,6 +63,7 @@ void
 csl_warning (const char *format,
 	     ...)
 {
+  static int warnabort = 2;
   va_list args;
 
   va_start (args, format);
@@ -70,6 +71,15 @@ csl_warning (const char *format,
   vfprintf (stderr, format, args);
   fprintf (stderr, "\n");
   va_end (args);
+
+  if (warnabort == 2)
+    {
+      char *v = getenv ("CSL_ABORT");
+
+      warnabort = atoi (v ? v : "0") ? TRUE : FALSE;
+    }
+  if (warnabort)
+    abort ();
 }
 
 /**
@@ -239,6 +249,23 @@ csl_realloc (void         *mem,
   return mem;
 }
 
+void*
+csl_memdup (void const  *mem,
+	    unsigned int n_bytes)
+{
+  void *block;
+
+  if (mem)
+    {
+      block = csl_malloc (n_bytes);
+      memcpy (block, mem, n_bytes);
+    }
+  else
+    block = NULL;
+
+  return block;
+}
+
 /**
  * Returns a pointer to a new string which is a duplicate of
  * string. Memory for the new string is obtained with csl_malloc and
