@@ -71,6 +71,8 @@ void*   csl_malloc      (unsigned int    n_bytes);
 void*   csl_malloc0     (unsigned int    n_bytes);
 void*   csl_realloc     (void           *mem,
 			 unsigned int    n_bytes);
+void*	csl_memdup	(void const	*mem,
+			 unsigned int	 n_bytes);
 char*   csl_strdup      (const char     *string);
 void    csl_strfreevn   (unsigned int    n,
 			 char          **str_p);
